aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMartijn Kaijser <machine.sanctum@gmail.com>2014-12-15 19:25:34 +0100
committerMartijn Kaijser <machine.sanctum@gmail.com>2014-12-15 19:25:34 +0100
commit6360c268f5e3944d138665ecadb94e83b6a135cb (patch)
tree58e1f53197758dd3e574ee7068afc6d56672f113
parentb39ca17e871658d7e21758be03aa300c3e1acc32 (diff)
parent1af4728043300f058de047c4690bab7068ffb8e0 (diff)
Merge pull request #5942 from FernetMenta/thumb
fix thumbnail extraction
-rw-r--r--xbmc/cores/dvdplayer/DVDCodecs/Video/DVDVideoCodecFFmpeg.cpp2
-rw-r--r--xbmc/cores/dvdplayer/DVDFileInfo.cpp4
2 files changed, 4 insertions, 2 deletions
diff --git a/xbmc/cores/dvdplayer/DVDCodecs/Video/DVDVideoCodecFFmpeg.cpp b/xbmc/cores/dvdplayer/DVDCodecs/Video/DVDVideoCodecFFmpeg.cpp
index 5fe315ca13..ae67480527 100644
--- a/xbmc/cores/dvdplayer/DVDCodecs/Video/DVDVideoCodecFFmpeg.cpp
+++ b/xbmc/cores/dvdplayer/DVDCodecs/Video/DVDVideoCodecFFmpeg.cpp
@@ -184,6 +184,8 @@ CDVDVideoCodecFFmpeg::CDVDVideoCodecFFmpeg() : CDVDVideoCodec()
m_dts = DVD_NOPTS_VALUE;
m_started = false;
m_decoderPts = DVD_NOPTS_VALUE;
+ m_codecControlFlags = 0;
+ m_requestSkipDeint = false;
}
CDVDVideoCodecFFmpeg::~CDVDVideoCodecFFmpeg()
diff --git a/xbmc/cores/dvdplayer/DVDFileInfo.cpp b/xbmc/cores/dvdplayer/DVDFileInfo.cpp
index 7ab72f304c..ef297bc2e0 100644
--- a/xbmc/cores/dvdplayer/DVDFileInfo.cpp
+++ b/xbmc/cores/dvdplayer/DVDFileInfo.cpp
@@ -224,8 +224,8 @@ bool CDVDFileInfo::ExtractThumb(const std::string &strPath,
memset(&picture, 0, sizeof(picture));
- // num streams * 80 frames, should get a valid frame, if not abort.
- int abort_index = pDemuxer->GetNrOfStreams() * 80;
+ // num streams * 160 frames, should get a valid frame, if not abort.
+ int abort_index = pDemuxer->GetNrOfStreams() * 160;
do
{
DemuxPacket* pPacket = pDemuxer->Read();